#[non_exhaustive]pub struct BatchStartViewerSessionRevocationViewerSessionBuilder { /* private fields */ }Expand description
A builder for BatchStartViewerSessionRevocationViewerSession.
Implementations
Sourceimpl BatchStartViewerSessionRevocationViewerSessionBuilder
impl BatchStartViewerSessionRevocationViewerSessionBuilder
Sourcepub fn channel_arn(self, input: impl Into<String>) -> Self
pub fn channel_arn(self, input: impl Into<String>) -> Self
The ARN of the channel associated with the viewer session to revoke.
This field is required.Sourcepub fn set_channel_arn(self, input: Option<String>) -> Self
pub fn set_channel_arn(self, input: Option<String>) -> Self
The ARN of the channel associated with the viewer session to revoke.
Sourcepub fn get_channel_arn(&self) -> &Option<String>
pub fn get_channel_arn(&self) -> &Option<String>
The ARN of the channel associated with the viewer session to revoke.
Sourcepub fn viewer_id(self, input: impl Into<String>) -> Self
pub fn viewer_id(self, input: impl Into<String>) -> Self
The ID of the viewer associated with the viewer session to revoke. Do not use this field for personally identifying, confidential, or sensitive information.
This field is required.Sourcepub fn set_viewer_id(self, input: Option<String>) -> Self
pub fn set_viewer_id(self, input: Option<String>) -> Self
The ID of the viewer associated with the viewer session to revoke. Do not use this field for personally identifying, confidential, or sensitive information.
Sourcepub fn get_viewer_id(&self) -> &Option<String>
pub fn get_viewer_id(&self) -> &Option<String>
The ID of the viewer associated with the viewer session to revoke. Do not use this field for personally identifying, confidential, or sensitive information.
Sourcepub fn viewer_session_versions_less_than_or_equal_to(self, input: i32) -> Self
pub fn viewer_session_versions_less_than_or_equal_to(self, input: i32) -> Self
An optional filter on which versions of the viewer session to revoke. All versions less than or equal to the specified version will be revoked. Default: 0.
Sourcepub fn set_viewer_session_versions_less_than_or_equal_to(
self,
input: Option<i32>,
) -> Self
pub fn set_viewer_session_versions_less_than_or_equal_to( self, input: Option<i32>, ) -> Self
An optional filter on which versions of the viewer session to revoke. All versions less than or equal to the specified version will be revoked. Default: 0.
Sourcepub fn get_viewer_session_versions_less_than_or_equal_to(&self) -> &Option<i32>
pub fn get_viewer_session_versions_less_than_or_equal_to(&self) -> &Option<i32>
An optional filter on which versions of the viewer session to revoke. All versions less than or equal to the specified version will be revoked. Default: 0.
Sourcepub fn build(
self,
) -> Result<BatchStartViewerSessionRevocationViewerSession, BuildError>
pub fn build( self, ) -> Result<BatchStartViewerSessionRevocationViewerSession, BuildError>
Consumes the builder and constructs a BatchStartViewerSessionRevocationViewerSession.
This method will fail if any of the following fields are not set: