#[non_exhaustive]pub struct StreamSessionSummary {
pub stream_id: Option<String>,
pub start_time: Option<DateTime>,
pub end_time: Option<DateTime>,
pub has_error_event: bool,
}Expand description
Summary information about a stream session.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.stream_id: Option<String>Unique identifier for a live or previously live stream in the specified channel.
start_time: Option<DateTime>Time when the channel went live. This is an ISO 8601 timestamp; note that this is returned as a string.
end_time: Option<DateTime>Time when the channel went offline. This is an ISO 8601 timestamp; note that this is returned as a string. For live streams, this is NULL.
has_error_event: boolIf true, this stream encountered a quota breach or failure.
Implementations
Sourceimpl StreamSessionSummary
impl StreamSessionSummary
Sourcepub fn stream_id(&self) -> Option<&str>
pub fn stream_id(&self) -> Option<&str>
Unique identifier for a live or previously live stream in the specified channel.
Sourcepub fn start_time(&self) -> Option<&DateTime>
pub fn start_time(&self) -> Option<&DateTime>
Time when the channel went live. This is an ISO 8601 timestamp; note that this is returned as a string.
Sourcepub fn end_time(&self) -> Option<&DateTime>
pub fn end_time(&self) -> Option<&DateTime>
Time when the channel went offline. This is an ISO 8601 timestamp; note that this is returned as a string. For live streams, this is NULL.
Sourcepub fn has_error_event(&self) -> bool
pub fn has_error_event(&self) -> bool
If true, this stream encountered a quota breach or failure.
Sourceimpl StreamSessionSummary
impl StreamSessionSummary
Sourcepub fn builder() -> StreamSessionSummaryBuilder
pub fn builder() -> StreamSessionSummaryBuilder
Creates a new builder-style object to manufacture StreamSessionSummary.